@@ -2,14 +2,14 @@
 #include <gsl/gsl_vector.h>
 #include "headers.h"
 
-void gr_KL_V_xi_n(const gsl_vector *V_xi_n, void *null, gsl_vector *df);
-void gr_KL_V_xi_e(const gsl_vector *V_xi_e, void *null, gsl_vector *df);
-void gr_KL_V_z_i(const gsl_vector *V_z_i, void *null, gsl_vector *df);
-void gr_KL_V_sigma2_i(const gsl_vector *V_sigma2_i, void *null, gsl_vector *df);
-void gr_KL_V_alpha_g(const gsl_vector *V_alpha_g, void *null, gsl_vector *df);
-void gr_KL_V_nu_g(const gsl_vector *V_nu_g, void *null, gsl_vector *df);
-void gr_KL_V_psi2_n(const gsl_vector *V_psi2_n, void *null, gsl_vector *df);
-void gr_KL_V_psi2_e(const gsl_vector *V_psi2_e, void *null, gsl_vector *df);
+void gr_KL_V_xi_n(const gsl_vector *V_xi_n, void *null, gsl_vector *df, Rf_params *params);
+void gr_KL_V_xi_e(const gsl_vector *V_xi_e, void *null, gsl_vector *df, Rf_params *params);
+void gr_KL_V_z_i(const gsl_vector *V_z_i, void *null, gsl_vector *df, Rf_params *params);
+void gr_KL_V_sigma2_i(const gsl_vector *V_sigma2_i, void *null, gsl_vector *df, Rf_params *params);
+void gr_KL_V_alpha_g(const gsl_vector *V_alpha_g, void *null, gsl_vector *df, Rf_params *params);
+void gr_KL_V_nu_g(const gsl_vector *V_nu_g, void *null, gsl_vector *df, Rf_params *params);
+void gr_KL_V_psi2_n(const gsl_vector *V_psi2_n, void *null, gsl_vector *df, Rf_params *params);
+void gr_KL_V_psi2_e(const gsl_vector *V_psi2_e, void *null, gsl_vector *df, Rf_params *params);
 
 int signum(double x)
 {
@@ -28,33 +28,33 @@ int signum(double x)
   }
 }
 
-void F (const gsl_vector *V, void *null, gsl_vector *df)
+void F (const gsl_vector *V, void *null, gsl_vector *df, Rf_params *params)
   {
   switch (*params->flag)
     {
     case 0: 
-      gr_KL_V_xi_n(V,NULL,df);
+      gr_KL_V_xi_n(V,NULL,df, params);
       break;
     case 6: 
-      gr_KL_V_xi_e(V,NULL,df);
+      gr_KL_V_xi_e(V,NULL,df, params);
       break;
     case 1: 
-      gr_KL_V_z_i(V,NULL,df);
+      gr_KL_V_z_i(V,NULL,df, params);
       break;
     case 2: 
-      gr_KL_V_sigma2_i(V,NULL,df);
+      gr_KL_V_sigma2_i(V,NULL,df, params);
       break;
     case 3: 
-      gr_KL_V_alpha_g(V,NULL,df);
+      gr_KL_V_alpha_g(V,NULL,df, params);
       break;
     case 4: 
-      gr_KL_V_nu_g(V,NULL,df);
+      gr_KL_V_nu_g(V,NULL,df, params);
       break;
     case 5: 
-      gr_KL_V_psi2_n(V,NULL,df);
+      gr_KL_V_psi2_n(V,NULL,df, params);
       break;
     case 7: 
-      gr_KL_V_psi2_e(V,NULL,df);
+      gr_KL_V_psi2_e(V,NULL,df, params);
       break;
     default: 
       break;
@@ -62,7 +62,7 @@ void F (const gsl_vector *V, void *null, gsl_vector *df)
   return;
   }
 
-void bb(double *lim, double *tol)
+void bb(double *lim, double *tol, Rf_params *params)
 {
   size_t iter = 0; 
   double val[2]={0.0,0.0};
@@ -78,9 +78,9 @@ void bb(double *lim, double *tol)
       {
       iter++;
       gsl_vector_set(ab, 0, 0.5*(gsl_vector_get(a,0)+gsl_vector_get(b,0)));
-      F(a,NULL,tmp);
+      F(a,NULL,tmp, params);
       val[0] = gsl_vector_get(tmp,0);
-      F(ab,NULL,tmp);
+      F(ab,NULL,tmp, params);
       val[1] = gsl_vector_get(tmp,0);
       if (signum(val[0])==signum(val[1])) gsl_vector_set(a,0,gsl_vector_get(ab,0)); 
       else gsl_vector_set(b,0,gsl_vector_get(ab,0));
